import { select, arc } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const smileyData = [
  {
    cx: width / 4,
    cy: height / 4,
    color: 'yellow',
    expression: 'happy',
  },
  {
    cx: (3 * width) / 4,
    cy: height / 4,
    color: 'lightblue',
    expression: 'surprised',
  },
  {
    cx: width / 4,
    cy: (3 * height) / 4,
    color: 'lightgreen',
    expression: 'sad',
  },
  {
    cx: (3 * width) / 4,
    cy: (3 * height) / 4,
    color: 'orange',
    expression: 'angry',
  },
  {
    cx: width / 2,
    cy: height / 2,
    color: 'pink',
    expression: 'content',
  },
];

smileyData.forEach((data) => {
  const g = svg
    .append('g')
    .attr('transform', `translate(${data.cx}, ${data.cy})`);

  const faceRadius = Math.min(width, height) / 5;

  // Face
  g.append('circle')
    .attr('r', faceRadius)
    .attr('fill', data.color)
    .attr('stroke', 'black');

  // Eyes (Different expressions can modify the shape or size)
  const eyeSpacing = 35;
  const eyeYOffset = -20;
  const eyeRadius = 10;

  const eyesG = g
    .append('g')
    .attr('transform', `translate(0, ${eyeYOffset})`);

  // Standard eyes for all, modify if specific expressions needed
  eyesG
    .append('circle')
    .attr('r', eyeRadius)
    .attr('cx', -eyeSpacing)
    .attr('fill', 'black');

  eyesG
    .append('circle')
    .attr('r', eyeRadius)
    .attr('cx', eyeSpacing)
    .attr('fill', 'black');

  // Eyebrows (Adjust for expressions)
  // Example for angry eyebrows
  const eyebrowWidth = 25;
  const eyebrowHeight = 5;
  const eyebrowYOffset = -35;

  // Adjustments for expressions
  let eyebrowAdjustment = `translate(${eyeSpacing}, 0)`;
  if (data.expression === 'angry') {
    eyebrowAdjustment = `translate(${eyeSpacing}, -10) skewX(20)`;
  }

  g.append('rect')
    .attr('width', eyebrowWidth)
    .attr('height', eyebrowHeight)
    .attr('transform', eyebrowAdjustment)
    .attr('fill', 'black');

  g.append('rect')
    .attr('width', eyebrowWidth)
    .attr('height', eyebrowHeight)
    .attr('transform', `scale(-1,1) ${eyebrowAdjustment}`)
    .attr('fill', 'black');

  // Mouth (Modify arc for different expressions)
  let mouthStartAngle = Math.PI / 2;
  let mouthEndAngle = (3 * Math.PI) / 2;
  let mouthYOffset = 25;

  if (data.expression === 'happy') {
    mouthStartAngle = Math.PI / 4;
    mouthEndAngle = (7 * Math.PI) / 4;
    mouthYOffset = 40; // Adjusting mouth position for happier expression
  }

  const mouthArc = arc()
    .innerRadius(faceRadius / 2)
    .outerRadius(faceRadius / 2 + 10)
    .startAngle(mouthStartAngle)
    .endAngle(mouthEndAngle);

  g.append('path')
    .attr('d', mouthArc())
    .attr(
      'transform',
      `translate(0, ${eyeYOffset + mouthYOffset})`,
    )
    .attr('fill', 'black');

  // Ears (Add for specific smileys)
  if (data.expression === 'surprised') {
    g.append('circle')
      .attr('r', eyeRadius * 1.5) // Larger ear radius
      .attr('cx', -(faceRadius + 20)) // Adjusted position
      .attr('fill', 'black');

    g.append('circle')
      .attr('r', eyeRadius * 1.5) // Larger ear radius
      .attr('cx', faceRadius + 20) // Adjusted position
      .attr('fill', 'black');
  }

  // Nose (Add for specific smileys)
  if (
    data.expression === 'happy' ||
    data.expression === 'sad'
  ) {
    g.append('circle')
      .attr('r', eyeRadius / 2)
      .attr('fill', 'black');
  }

  // Beard (Add for specific smileys)
  if (data.expression === 'content') {
    g.append('path')
      .attr(
        'd',
        `M${-faceRadius / 2},20 A${faceRadius / 2},${faceRadius / 2} 0 0,1 ${faceRadius / 2},20`,
      )
      .attr('fill', 'black');
  }

  // Hair (Add for specific smileys)
  if (data.expression === 'angry') {
    g.append('path')
      .attr(
        'd',
        `M${-faceRadius},${-faceRadius / 2} q${faceRadius / 2}, ${-faceRadius / 2}, ${faceRadius * 2},0`,
      )
      .attr('stroke', 'black')
      .attr('fill', 'none');
  }
});
